services

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MulVal

type MulVal struct {
	pulumi.ResourceState

	Namespace pulumi.StringOutput
	PodLabels pulumi.StringMapOutput
	Endpoint  pulumi.StringOutput
	// contains filtered or unexported fields
}

func NewMulVal

func NewMulVal(ctx *pulumi.Context, name string, args *MulValArgs, opts ...pulumi.ResourceOption) (*MulVal, error)

type MulValArgs

type MulValArgs struct {
	Tag pulumi.StringPtrInput

	// Registry define from where to fetch the MulVal Docker images.
	// If set empty, defaults to Docker Hub.
	Registry pulumi.StringPtrInput

	// LogLevel defines the level at which to log.
	LogLevel pulumi.StringInput

	Namespace pulumi.StringInput

	// PVCAccessModes defines the access modes supported by the PVC.
	PVCAccessModes pulumi.StringArrayInput

	// PVCStorageSize enable to configure the storage size of the PVC MulVal
	// will write into (store Pulumi stacks, data persistency, ...).
	// Default to 2Gi.
	// See https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#meaning-of-memory
	// for syntax.
	PVCStorageSize pulumi.StringInput

	PgToAPIServerTemplate pulumi.StringPtrInput

	PostgresOperatorNamespace pulumi.StringPtrInput

	StorageClassName pulumi.StringInput

	// RomeoClaimName, if set, will turn on the coverage export of MulVal for later download.
	RomeoClaimName pulumi.StringInput

	// Requests for the MulVal container. For more infos:
	// https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
	Requests pulumi.StringMapInput

	// Limits for the MulVal container. For more infos:
	// https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
	Limits pulumi.StringMapInput

	Swagger, UI bool

	OTel *common.OTelArgs
	// contains filtered or unexported fields
}

Directories

Path Synopsis

Jump to