Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MulVal ¶
type MulVal struct {
pulumi.ResourceState
PodLabels pulumi.StringMapOutput
Endpoint pulumi.StringOutput
// contains filtered or unexported fields
}
func NewMulVal ¶
func NewMulVal(ctx *pulumi.Context, name string, args *MulValArgs, opts ...pulumi.ResourceOption) (*MulVal, error)
type MulValArgs ¶
type MulValArgs struct {
// Namespace to which deploy the MulVal resources.
// It is different from the namespace the MulVal will deploy instances to,
// which will be created on the fly.
Namespace pulumi.StringInput
// AdditionalLabels to pass to the namespace, mostly for filtering purposes.
AdditionalLabels pulumi.StringMapInput
// Tag defines the specific tag to run MulVal to.
// If not specified, defaults to "latest".
Tag pulumi.StringPtrInput
// Registry define from where to fetch the MulVal Docker images.
// If set empty, defaults to Docker Hub.
// Authentication is not supported, please provide it as Kubernetes-level configuration.
Registry pulumi.StringPtrInput
// LogLevel defines the level at which to log.
LogLevel pulumi.StringInput
// RomeoClaimName, if set, will turn on the coverage export of MulVal for later download.
RomeoClaimName pulumi.StringInput
// Requests for the MulVal container. For more infos:
// https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
Requests pulumi.StringMapInput
// Limits for the MulVal container. For more infos:
// https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
Limits pulumi.StringMapInput
Swagger, UI bool
NatsEndpoint pulumi.StringInput
PgsqlEndpoint pulumi.StringInput
Otel *common.OTelArgs
// contains filtered or unexported fields
}
type Namespace ¶
type Namespace struct {
pulumi.ResourceState
// Name of the namespace. Is going to be appended a 8-char random string
// for parallel deployments within a single Kubernetes cluster (e.g. CI).
// Pass it to the namespacable resources to deploy them into.
Name pulumi.StringOutput
// Labels of the namespace.
Labels pulumi.StringMapOutput
// contains filtered or unexported fields
}
Namespace is an isolated and secured Kubernetes namespace, with security annotations for enforce and warn to baseline, and versions to latest. It is deployed with a basic set of network policies that ensure the network isolation toward adjacent namespaces, and deny all non-explicitly-granted traffic.
func NewNamespace ¶
func NewNamespace(ctx *pulumi.Context, name string, args *NamespaceArgs, opts ...pulumi.ResourceOption) (*Namespace, error)
NewNamespace creates a new *Namespace.
type NamespaceArgs ¶
type NamespaceArgs struct {
// Name is an optional value that defines the namespace name.
Name pulumi.StringInput
// AdditionalLabels to pass to the namespace, mostly for filtering purposes.
AdditionalLabels pulumi.StringMapInput
}
type Nats ¶
type Nats struct {
pulumi.ResourceState
Endpoint pulumi.StringOutput
PodLabels pulumi.StringMapOutput
// contains filtered or unexported fields
}
type NatsArgs ¶
type NatsArgs struct {
Namespace pulumi.StringInput
Replicas pulumi.IntInput
StorageClassName pulumi.StringInput
// contains filtered or unexported fields
}
type PostgreSQL ¶
type PostgreSQL struct {
pulumi.ResourceState
Endpoint pulumi.StringOutput
PodLabels pulumi.StringMapOutput
// contains filtered or unexported fields
}
func NewPostgreSQL ¶
func NewPostgreSQL( ctx *pulumi.Context, name string, args *PostgreSQLArgs, opts ...pulumi.ResourceOption, ) (*PostgreSQL, error)
NewPostgreSQL creates a HA PostgreSQL cluster. The https://github.com/zalando/postgres-operator with CRDs need to be installed on the cluster before.
type PostgreSQLArgs ¶
type PostgreSQLArgs struct {
DatabaseName pulumi.StringInput
Namespace pulumi.StringInput
Registry pulumi.StringPtrInput
// PgToAPIServerTemplate is a Go text/template that defines the NetworkPolicy
// YAML schema to use.
// If none set, it is defaulted to a cilium.io/v2 CiliumNetworkPolicy.
PgToAPIServerTemplate pulumi.StringPtrInput
ClusterNamePrefix pulumi.StringPtrInput
// PostgresOperatorNamespace is the namespace where the postgres-operator
// from cnpg is installed.
// If none set, it is defaulted to "default" namespace.
PostgresOperatorNamespace pulumi.StringPtrInput
StorageClassName pulumi.StringInput
Replicas pulumi.IntInput
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.